@@ -352,8 +352,14 @@ def get_customer_consumption(uuid):
             service_code=SERVICE_CODE
             )
     else:
+        bool_start = request.args.get('bool_start', False)
         start = request.args.get('start', None)
         stop = request.args.get('stop', None)
+        if bool_start:
+            if bool_start.lower() == 'true':
+                bool_start = True
+            else:
+                bool_start = False
         if not start:
             start = datetime.now() - timedelta(30)
         else:
@@ -386,7 +392,8 @@ def get_customer_consumption(uuid):
             start.date(),
             stop.date(),
             True,
-            product_out_fup
+            product_out_fup,
+            bool_start
             )
         return jsonify(infos)
 
