@@ -15,6 +15,7 @@ les vérifications se font donc en local.
 from .consts import FUPDB_CREDENTIALS
 
 import records
+import psycopg2
 
 
 __all__ = [
@@ -25,6 +26,17 @@ __all__ = [
     ]
 
 
+def connexion(**kwargs):
+    con = psycopg2.connect(
+        user=kwargs.get('user'),
+        password=kwargs.get('password'),
+        host=kwargs.get('host'),
+        port=kwargs.get('port'),
+        database=kwargs.get('name')
+    )
+    return con
+
+
 def database_url(**kwargs):
     url = '{eng}://{user}:{password}@{host}:{port}/{name}'.format(
         eng=kwargs.get('engine'),
