@@ -473,9 +473,8 @@ class Product_GP(object):
                                 "seuil de {limit} Go de la politique "
                                 "de bon usage de votre offre Internet, "
                                 "le debit de votre connexion est donc "
-                                "restreint. Nous vous invitons a "
-                                "consulter vos dernieres consommations "
-                                "sur votre espace client "
+                                "restreint. Vous pouvez consulter "
+                                "vos consommations sur votre espace client "
                                 "http://espace-client.blueline.mg"
                                 ).format(
                                     limit=round(self.limit / 1000000000)
